@@ -1,4 +1,5 @@
 import requests
+from datetime import datetime
 class Tweet:
 	def __init__(self, id):
 		self.id = id
@@ -7,7 +8,8 @@ class Tweet:
 		except:
 			self.__data=dict()
 		self.__dict__.update(self.__data)
-		self.created_at = datetime.strptime(self.created_at,'%Y-%m-%dT%H:%M:%S.%fZ')
+		if 'created_at' in self.__data.keys():
+			self.created_at = datetime.strptime(self.created_at,'%Y-%m-%dT%H:%M:%S.%fZ')
 	
 	def __str__(self):
 		return f"tweet id: {self.id}"
